/*
 * Copyright (C) 2000 - 2024 Silverpeas
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * As a special exception to the terms and conditions of version 3.0 of
 * the GPL, you may redistribute this Program in connection with Free/Libre
 * Open Source Software ("FLOSS") applications as described in Silverpeas's
 * FLOSS exception. You should have received a copy of the text describing
 * the FLOSS exception, and it is also available here:
 * "https://www.silverpeas.org/legal/floss_exception.html"
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

package org.silverpeas.components.silvercrawler.servlets.handlers;

import org.silverpeas.components.silvercrawler.control.SilverCrawlerSessionController;
import org.apache.commons.fileupload.FileItem;
import org.silverpeas.core.util.file.FileUploadUtil;
import org.silverpeas.core.web.http.HttpRequest;
import org.silverpeas.kernel.util.StringUtil;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * Handler for use case : upload file form has been submitted.
 * @author Ludovic Bertin
 */
public class UploadFileHandler extends FunctionHandler {

  @Override
  public String getDestination(SilverCrawlerSessionController sessionController,
      HttpServletRequest req) throws Exception {

    // Is User has admin or publisher profile
    String userHighestRole = getUserHighestRole(sessionController);
    boolean isAdminOrPublisher =
        (userHighestRole.equals("admin") || userHighestRole.equals("publisher"));

    if (!isAdminOrPublisher) {
      req.setAttribute("errorMessage", "User has not admin/publisher rights");
      return "operationFailed.jsp";
    }

    // Retrieve File and policy for existing files
    HttpRequest request = HttpRequest.decorate(req);
    List<FileItem> parameters = request.getFileItems();
    FileItem file = FileUploadUtil.getFile(parameters, "newFile");
    boolean replaceFile =
        StringUtil.getBooleanValue(FileUploadUtil.getParameter(parameters, "replaceExistingFile"));

    // Save File
    try {
      sessionController.saveFile(file, replaceFile);
    } catch (Exception e) {
      request.setAttribute("errorMessage", e.getMessage());
    }

    // returns page to redirect to
    return HandlerProvider.getHandler("ViewDirectory").getDestination(sessionController, request);
  }

}
